@@ -19,11 +19,12 @@ class BranchDistanceSuiteFitnessFunction(asff.AbstractSuiteFitnessFunction):
     """A fitness function based on branch distances and entered code objects."""
 
     def compute_fitness_values(
-        self, individual: tsc.TestSuiteChromosome,
+        self,
+        individual: tsc.TestSuiteChromosome,
     ) -> ff.FitnessValues:
         results = self._run_test_suite(individual)
         _, merged_trace = self.analyze_traces(results)
-        tracer: ExecutionTracer = self._executor.get_tracer()
+        tracer: ExecutionTracer = self._executor.tracer
 
         return ff.FitnessValues(
             self._compute_fitness(merged_trace, tracer.get_known_data()),
