@@ -76,16 +76,46 @@ class ExecutionTracer:
     # The returned tuple for each computation is (true distance, false distance).
     # pylint: disable=arguments-out-of-order
     _DISTANCE_COMPUTATIONS: Dict[Compare, Callable[[Any, Any], Tuple[float, float]]] = {
-        Compare.EQ: lambda val1, val2: (_eq(val1, val2), _neq(val1, val2),),
-        Compare.NE: lambda val1, val2: (_neq(val1, val2), _eq(val1, val2),),
-        Compare.LT: lambda val1, val2: (_lt(val1, val2), _le(val2, val1),),
-        Compare.LE: lambda val1, val2: (_le(val1, val2), _lt(val2, val1),),
-        Compare.GT: lambda val1, val2: (_lt(val2, val1), _le(val1, val2),),
-        Compare.GE: lambda val1, val2: (_le(val2, val1), _lt(val1, val2),),
-        Compare.IN: lambda val1, val2: (_in(val1, val2), _nin(val1, val2),),
-        Compare.NOT_IN: lambda val1, val2: (_nin(val1, val2), _in(val1, val2),),
-        Compare.IS: lambda val1, val2: (_is(val1, val2), _isn(val1, val2),),
-        Compare.IS_NOT: lambda val1, val2: (_isn(val1, val2), _is(val1, val2),),
+        Compare.EQ: lambda val1, val2: (
+            _eq(val1, val2),
+            _neq(val1, val2),
+        ),
+        Compare.NE: lambda val1, val2: (
+            _neq(val1, val2),
+            _eq(val1, val2),
+        ),
+        Compare.LT: lambda val1, val2: (
+            _lt(val1, val2),
+            _le(val2, val1),
+        ),
+        Compare.LE: lambda val1, val2: (
+            _le(val1, val2),
+            _lt(val2, val1),
+        ),
+        Compare.GT: lambda val1, val2: (
+            _lt(val2, val1),
+            _le(val1, val2),
+        ),
+        Compare.GE: lambda val1, val2: (
+            _le(val2, val1),
+            _lt(val1, val2),
+        ),
+        Compare.IN: lambda val1, val2: (
+            _in(val1, val2),
+            _nin(val1, val2),
+        ),
+        Compare.NOT_IN: lambda val1, val2: (
+            _nin(val1, val2),
+            _in(val1, val2),
+        ),
+        Compare.IS: lambda val1, val2: (
+            _is(val1, val2),
+            _isn(val1, val2),
+        ),
+        Compare.IS_NOT: lambda val1, val2: (
+            _isn(val1, val2),
+            _is(val1, val2),
+        ),
     }
 
     def __init__(self) -> None:
@@ -139,11 +169,11 @@ class ExecutionTracer:
         """
         return not self._enabled
 
-    def _enable(self) -> None:
+    def enable(self) -> None:
         """Enable tracing."""
         self._enabled = True
 
-    def _disable(self) -> None:
+    def disable(self) -> None:
         """Disable tracing."""
         self._enabled = False
 
@@ -216,7 +246,7 @@ class ExecutionTracer:
             return
 
         try:
-            self._disable()
+            self.disable()
             assert (
                 predicate in self._known_data.existing_predicates
             ), "Cannot trace unknown predicate"
@@ -226,7 +256,7 @@ class ExecutionTracer:
 
             self._update_metrics(distance_false, distance_true, predicate)
         finally:
-            self._enable()
+            self.enable()
 
     def executed_bool_predicate(self, value, predicate: int):
         """A predicate that is based on a boolean value was executed.
@@ -239,7 +269,7 @@ class ExecutionTracer:
             return
 
         try:
-            self._disable()
+            self.disable()
             assert (
                 predicate in self._known_data.existing_predicates
             ), "Cannot trace unknown predicate"
@@ -252,7 +282,7 @@ class ExecutionTracer:
 
             self._update_metrics(distance_false, distance_true, predicate)
         finally:
-            self._enable()
+            self.enable()
 
     def _update_metrics(
         self, distance_false: float, distance_true: float, predicate: int
