@@ -79,7 +79,9 @@ class TestFactory:
             )
         elif isinstance(statement, f_stmt.FieldStatement):
             self.add_field(
-                test_case, statement.field, position=test_case.size(),
+                test_case,
+                statement.field,
+                position=test_case.size(),
             )
         elif isinstance(statement, prim.PrimitiveStatement):
             self.add_primitive(test_case, statement, position=test_case.size())
@@ -196,13 +198,15 @@ class TestFactory:
             position = position + new_length - length
 
             statement = par_stmt.ConstructorStatement(
-                test_case=test_case, generic_callable=constructor, args=parameters,
+                test_case=test_case,
+                generic_callable=constructor,
+                args=parameters,
             )
             return test_case.add_statement(statement, position)
         except BaseException as exception:
             raise ConstructionFailedException(
-                f"Failed to add constructor for {constructor} " f"due to {exception}."
-            )
+                f"Failed to add constructor for {constructor}"
+            ) from exception
 
     # pylint: disable=too-many-arguments
     def add_method(
@@ -247,7 +251,7 @@ class TestFactory:
         length = test_case.size()
         if callee is None:
             callee = self._create_or_reuse_variable(
-                test_case, method.owner, position, recursion_depth, allow_none=True
+                test_case, method.owner, position, recursion_depth, allow_none=False
             )
         assert callee, "The callee must not be None"
         parameters: List[vr.VariableReference] = self.satisfy_parameters(
@@ -365,7 +369,9 @@ class TestFactory:
         position = position + new_length - length
 
         statement = par_stmt.FunctionStatement(
-            test_case=test_case, generic_callable=function, args=parameters,
+            test_case=test_case,
+            generic_callable=function,
+            args=parameters,
         )
         return test_case.add_statement(statement, position)
 
@@ -400,8 +406,8 @@ class TestFactory:
     ) -> int:
         """Insert a random statement up to the given position.
 
-        If the insertion was successful, the position at which the statement was inserted
-        is returned, otherwise -1.
+        If the insertion was successful, the position at which the statement was
+        inserted is returned, otherwise -1.
 
         Args:
             test_case: The test case to add the statement to
@@ -810,7 +816,7 @@ class TestFactory:
 
         Returns:
             Whether or not the objects are sufficient to satisfy the dependencies
-         """
+        """
         for type_ in dependencies:
             found = False
             for var in objects:
@@ -894,8 +900,10 @@ class TestFactory:
                 )
             if not var:
                 raise ConstructionFailedException(
-                    f"Failed to create variable for type {parameter_type} "
-                    f"at position {position}",
+                    (
+                        f"Failed to create variable for type {parameter_type} "
+                        + f"at position {position}"
+                    ),
                 )
 
             parameters.append(var)
@@ -1039,7 +1047,8 @@ class TestFactory:
         allow_none: bool,
         exclude: Optional[vr.VariableReference] = None,
     ) -> Optional[vr.VariableReference]:
-        # We only select a concrete type e.g. from a union, when we are forced to choose one.
+        # We only select a concrete type e.g. from a union, when we are forced to
+        # choose one.
         parameter_type = self._test_cluster.select_concrete_type(parameter_type)
 
         if not parameter_type:
@@ -1051,7 +1060,10 @@ class TestFactory:
             )
         if is_primitive_type(parameter_type):
             return self._create_primitive(
-                test_case, parameter_type, position, recursion_depth,
+                test_case,
+                parameter_type,
+                position,
+                recursion_depth,
             )
         if type_generators := self._test_cluster.get_generators_for(parameter_type):
             return self._attempt_generation_for_type(
